==> balcony-0.0.38.tar.gz: balcony-0.0.38/balcony/custom_nodes/codebuild.py <==
try:                                                                                                                                                                                       
    from ..nodes import ResourceNode                                                                                                                                                       
    from ..logs import get_logger                                                                                                                                                          
except ImportError:                                                                                                                                                                        
    from nodes import ResourceNode                                                                                                                                                         
    from logs import get_logger                                                                                                                                                            
from typing import List, Set, Dict, Tuple, Optional, Union                                                                                                                                 
logger = get_logger(__name__)                                                                                                                                                              
                                                                                                                                                                                            
class BuildsForProject(ResourceNode, service_name='codebuild', name='BuildsForProject'):                                                                                                   
    def __init__(self, *args, **kwargs):                                                                                                                                                   
        super().__init__(*args, **kwargs)                                                                                                                                                  
                                                                                                                                                                                            
    def get_operations_relations(self, operation_name) -> Tuple[List[Dict], None]:                                                                                                               
        result, err = super().get_operations_relations(operation_name)                                                                                                                     
        # manipulate `result` or return your own value                                                                                                                                     
        return result, err

==> balcony-0.0.66.tar.gz: balcony-0.0.66/balcony/custom_nodes/codebuild.py <==
try:                                                                                                                                                                                       
    from ..nodes import ResourceNode                                                                                                                                                       
    from ..config import get_logger                                                                                                                                                          
except ImportError:                                                                                                                                                                        
    from nodes import ResourceNode                                                                                                                                                         
    from config import get_logger                                                                                                                                                            
from typing import List, Set, Dict, Tuple, Optional, Union                                                                                                                                 
logger = get_logger(__name__)                                                                                                                                                              
                                                                                                                                                                                            
class BuildsForProject(ResourceNode, service_name='codebuild', name='BuildsForProject'):                                                                                                   
    def __init__(self, *args, **kwargs):                                                                                                                                                   
        super().__init__(*args, **kwargs)                                                                                                                                                  
                                                                                                                                                                                            
    def get_operations_relations(self, operation_name) -> Tuple[List[Dict], None]:                                                                                                               
        result, err = super().get_operations_relations(operation_name)                                                                                                                     
        # manipulate `result` or return your own value                                                                                                                                     
        return result, err
